@@ -184,7 +184,7 @@ class TxFrequencyProcType(Serializable, Arrayable):
         if array is None:
             return None
         if isinstance(array, (numpy.ndarray, list, tuple)):
-            if len(array) < 2:
+            if len(array) != 2:
                 raise ValueError('Expected array to be of length 2, and received {}'.format(array))
             return cls(MinProc=array[0], MaxProc=array[1])
         raise ValueError('Expected array to be numpy.ndarray, list, or tuple, got {}'.format(type(array)))
@@ -246,7 +246,7 @@ class DistortionType(Serializable):
     A = FloatDescriptor(
         'A', _required, strict=DEFAULT_STRICT,
         docstring='Absolute amplitude scale factor.')  # type: float
-    # receive distorion matrix
+    # receive distortion matrix
     F1 = ComplexDescriptor(
         'F1', _required, strict=DEFAULT_STRICT,
         docstring='Receive distortion element (2,2).')  # type: complex
@@ -538,7 +538,7 @@ class ImageFormationType(Serializable):
         if RadarCollection is not None and RadarCollection.TxFrequency is not None and \
                 RadarCollection.TxFrequency.Min is not None and RadarCollection.TxFrequency.Max is not None:
             # this is based on the assumption that the entire transmitted bandwidth was processed.
-            if self.TxFrequencyProc is not None:
+            if self.TxFrequencyProc is None:
                 self.TxFrequencyProc = TxFrequencyProcType(
                     MinProc=RadarCollection.TxFrequency.Min, MaxProc=RadarCollection.TxFrequency.Max)
                 # how would it make sense to set only one end?
