@@ -1,5 +1,5 @@
 """
-**This sub-package is a work in progress to encapsulate pythonic object oriented SICD structure 1.1 (2014-09-30).**
+**This sub-package is a work in progress to encapsulate pythonic object-oriented SICD structure 1.1 (2014-09-30).**
 
 This purpose of doing it this way is to encourage effective documentation and streamlined use of the SICD information.
 This provides more robustness than using structures with no built-in validation, and more flexibility than using the
